@@ -2,11 +2,12 @@ use std::process::ExitCode;
 use std::{env, io};
 
 use anyhow::anyhow;
-use camino::Utf8Path;
 use clap::Parser;
 use clap_verbosity_flag::Verbosity;
 use indexmap::IndexSet;
+use pkgcraft::cli::colorize;
 use pkgcraft::config::Config as PkgcraftConfig;
+use pkgcraft::repo::RepoFormat;
 use pkgcraft::utils::current_dir;
 use pkgcruft::report::ReportLevel;
 use pkgcruft::reporter::{FancyReporter, Reporter};
@@ -25,9 +26,8 @@ pub(crate) struct Command {
     #[command(flatten)]
     verbosity: Verbosity,
 
-    /// enable/disable color support
-    #[arg(long, value_name = "BOOL", hide_possible_values = true)]
-    color: Option<bool>,
+    #[command(flatten)]
+    color: colorchoice_clap::Color,
 
     /// Parallel jobs to run
     #[arg(short, long, default_value_t = num_cpus::get())]
@@ -37,31 +37,28 @@ pub(crate) struct Command {
 fn main() -> anyhow::Result<ExitCode> {
     let args = Command::parse();
 
+    // set color choice
+    args.color.write_global();
+
     // create formatting subscriber that uses stderr
     let level = args.verbosity.log_level_filter();
-    let mut subscriber = tracing_subscriber::fmt()
+    let subscriber = tracing_subscriber::fmt()
         .with_max_level(level.as_trace())
-        .with_writer(io::stderr);
-
-    // forcibly enable or disable subscriber output color
-    if let Some(value) = args.color {
-        subscriber = subscriber.with_ansi(value);
-    }
+        .with_writer(io::stderr)
+        .with_ansi(colorize!(&io::stderr()));
 
     // initialize global subscriber
     subscriber.init();
 
-    let mut stdout = io::stdout().lock();
+    let mut stdout = anstream::stdout().lock();
 
     // load repo from the current working directory
     let path = current_dir()?;
     let mut config = PkgcraftConfig::new("pkgcraft", "");
     let repo = config
-        .add_nested_repo_path(&path, 0)
-        .map_err(|e| anyhow!("invalid repo: {e}"))?;
-    let repo = repo
+        .add_format_repo_nested_path(&path, 0, RepoFormat::Ebuild)?
         .into_ebuild()
-        .map_err(|e| anyhow!("invalid ebuild repo: {path}: {e}"))?;
+        .expect("failed loading repo");
     config
         .finalize()
         .map_err(|e| anyhow!("failed finalizing config: {e}"))?;
@@ -84,7 +81,7 @@ fn main() -> anyhow::Result<ExitCode> {
     // determine target Cpns from diff
     let mut cpns = IndexSet::new();
     for delta in diff.deltas() {
-        if let Some(path) = delta.new_file().path().and_then(Utf8Path::from_path)
+        if let Some(path) = delta.new_file().path()
             && let Ok(cpn) = repo.cpn_from_path(path)
         {
             cpns.insert(cpn);
